#
# spec file for package kst
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2011 Christian Trippe ctrippe@opensuse.org
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kst
Version:        2.0.8
Release:        14.6
Summary:        Real-Time Data Viewing and Plotting Tool with Basic Data Analysis Functionality
License:        GPL-2.0-or-later
Group:          Productivity/Graphics/Visualization/Graph
URL:            https://kst-plot.kde.org/
Source:         Kst-%{version}.tar.gz
# PATCH-FIX-UPSTREAM gsl2-support.patch -- fixes build with GSL-2.0
Patch0:         gsl2-support.patch
# PATCH-FIX-UPSTREAM -- Fix-build-with-Qt-511.patch -- Fixes build with Qt 5.11
Patch1:         Fix-build-with-Qt-511.patch
# PATCH-FIX-UPSTREAM
Patch2:         0001-Fix-build-with-CMake-3.20.patch
BuildRequires:  Mesa-devel
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gsl-devel
BuildRequires:  libmatio-devel
BuildRequires:  libnetcdf_c++-devel
BuildRequires:  libqt5-linguist
BuildRequires:  netcdf-devel
BuildRequires:  readline-devel
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt5Concurrent)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5PrintSupport)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5Xml)
BuildRequires:  pkgconfig(cfitsio)
Obsoletes:      python-kst < %{version}

%description
Kst is a data plotting and viewing program. Some of the features include:

- Robust plotting of live "streaming" data
- Powerful keyboard and mouse plot manipulation
- Powerful plug-in and extension support
- Large selection of built-in plotting and data manipulation functions,
  such as histograms, equations, and power spectra
- Color mapping and contour mapping capabilities for three-dimensional data
- Monitoring of events and notification support
- Built-in filtering and curve fitting capabilities
- Convenient command line interface
- Powerful graphical user interface

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/KDE
Requires:       %{name} = %{version}
Requires:       cmake(Qt5Concurrent)
Requires:       cmake(Qt5Core)
Requires:       cmake(Qt5Network)
Requires:       cmake(Qt5PrintSupport)
Requires:       cmake(Qt5Widgets)
Requires:       cmake(Qt5Xml)

%description devel
Development libraries and headers needed to build software
making use of %{name}

%prep
%autosetup -p1 -n Kst-2.0.8

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
EXTRA_FLAGS="-Dkst_install_prefix=%{_prefix} \
             -Dkst_rpath=0 \
             -Dkst_install_libdir=%{_lib} \
             -Dkst_release=1 \
             -Dkst_dbgsym=1 \
             -Dkst_python=0 \
             -Dkst_qt5=1"

%cmake $EXTRA_FLAGS
%cmake_build

%install
%cmake_install
%suse_update_desktop_file -r %{name}2 Qt KDE Science Math
%fdupes %{buildroot}

%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%license COPYING*
%doc AUTHORS NEWS README
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/*
%dir %{_datadir}/icons/hicolor/*/apps
%dir %{_datadir}/kst
%dir %{_datadir}/kst/locale
%{_bindir}/%{name}2
%{_datadir}/applications/%{name}2.desktop
%{_datadir}/applnk/
%{_datadir}/icons/hicolor/*/apps/*%{name}.*
%{_datadir}/kst/locale/kst_common_*.qm
%{_datadir}/mimelink/
%{_libdir}/%{name}2/
%{_libdir}/lib%{name}*.so.*
%{_mandir}/man1/%{name}2.1%{?ext_man}

%files devel
%license COPYING*
%{_libdir}/*.so
%{_libdir}/lib%{name}2app.a

%changelog
* Fri Jan  6 2023 Christophe Marin <christophe@krop.fr>
- Update build constraints
* Fri Jan  6 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Drop libnetcdf BuildRequires: this seems not to be required (and
  does no longer exist).
* Thu Dec 15 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Replace libcfitsio-devel with pkgconfig(cfitsio): the devel
  package was renamed 8 years ago. Instead of caring for the name,
  we care for the symbol CMake is looking for.
* Wed May 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to fix build with CMake 3.20:
  * 0001-Fix-build-with-CMake-3.20.patch
* Tue Jul 21 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Add _constraints min disk space for PowerPC to avoid build error
* Thu Jan 16 2020 Christophe Giboudeaux <christophe@krop.fr>
- Remove the optional getdata dependency.
  The Getdata development stalled and it still requires Python 2.
* Sat Sep  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Use -ffat-lto-objects
* Fri Feb 15 2019 wbauer@tmo.at
- Use %%cmake and %%cmake_install macros
* Sun Jun  3 2018 christophe@krop.fr
- Add Fix-build-with-Qt-511.patch.
- Run spec-cleaner
* Thu Feb 22 2018 aloisio@gmx.com
- Switched build to Qt5 for TW and Leap 15
* Thu Aug  4 2016 wbauer@tmo.at
- Add gsl2-support.patch to fix build with GSL-2.x
* Mon Aug 24 2015 toddrme2178@gmail.com
- Require correct libnetcdf version.
* Tue Jul 29 2014 dmitry_r@opensuse.org
- Build with MAT files support
* Mon Jul 21 2014 ctrippe@opensuse.org
- Update to 2.0.8
  1) Data sources
  * A new datasource: sourcelist, which is a successive list of otherwise identical datasources
  * Another new datasource: FITS tables, contributed by a new contributor: Nicholas Chapman. Welcome!
  * ASCII improved once again to support huge files (>8 GB!)
  * Add option how empty ASCII columns should be handled (NaN, copy previous, interpolate)
  * Improve ASCII config dialog layout
  * Handle data sources which are temporarily typed into the data source selector,
    but which are not actually used and when a data source is deleted, delete its slave primitives as well
  2) Main new features
  * Thanks to the awesome job done by the KDE internationalization team, Kst 2.0.8 is now available in the following   languages: ca ca@valencia de en_GB fr nl pl pt pt_BR sv uk. Kst will default to using the system language, if available. To override this, launch with e.g. "LANG=en ./kst2"
  * A progress bar appears when parsing large ASCII files, very nice when it takes long with huge files!
  * Reworked view vector values allowing easy comparison of vectors and changing the number of digits shown - a first step towards a more table-centric view as in other plotting tools
  * Add filtering to the data manager to allow finding items easily in complex sessions
  * Add an "unwind" filter: for data fields that have wrapped. For example, an angle (0-360 degrees) which has rotated several times
  * New plugin to compute the "activity level" of a signal as the product of standard deviation and number of reversals over a sliding window.
  3) Misc. improvements
  * Scripting: major rework underway - still ongoing. Hopefully Python scripting will be supported under Windows as well in the next version
  * Add a -T command line option which creates a new tab
  * Equations: add 'degree' versions of the trig functions: sind, cosd, etc as well as atan2(x,y)
  * Avoid having to type * before/after the text in the editmultiple widget
  * HOWTO explaining how to add a plugin
  * Improvements to use the whole available space in the scalar/vector/matrix/string selectors
  * To reduce the impact of latent/glitchy file system situations, delay reloading a file which looks like it has shrunk
  * Use "Spectrogram" instead of "CSD"
  * Option to use the "native" Qt graphics system if "use raster" is not selected (native works far better for remote X)
  4) Bug fixes
  * Scalar selector improvements
  * Many improvements in the update system and propagation of data source configuration changes
  * Solve wrong vector selection in shift and differentiation plugins (kde#325393)
  * Fix annoying bug breaking the recent data file and session lists (kde#325086)
  * Only reset starting frame to skip boundry if in count from end mode -> allow selecting the right subsamples when using skip in other cases
  * Various fixes to ASCII configuration to ensure that we don't parse the whole file when we only want to change the settings
  * Make sure custom color applies to all lines of a multi line text label
  * Don't crash when there is an exception while searching for rows
  * Some improvements to defaults in filter plugins
  * Fix enabling/disabling widgets in FFT options (kde#328371)
  * In datawizard, don't create plots if no curves (kde#307723)
  * Update curve names in plot dialog when changed (kde#318139)
- Remove the python subpackage as this is still under development
  and should not be build according to upstream.
* Thu Jul 18 2013 ctrippe@opensuse.org
- Update to 2.0.7
  * Automatic formatting of X axis time display from the datawizard when reading string-formatted time
  * More speed for files with very many columns
  * Scripting: major rework adding support for histograms, spectrums and plugins
  * Allow the x and y plot labels to be changed from the command line
  * Fix a bug where if you drag a plot to a new tab, it wasn't picked up by future autoformat actions nor listed in plot lists
  * Cumulative sum plugin now returns a vector of the same size as the input vector
  * Fix toggling tied zoom
  * Save/reload "automatically scale number axis" setting in plots.
  * Fix regression in which re-scaling font sizes when adding plots didn't work.
  * Fix gaussian + Lorentzian fits so that they actually fit
  * Respect dialog defaults and curve properties for point density.
  * Restore proper behavior of font scaling when adding plots to tabs
* Fri Mar 15 2013 dmitry_r@opensuse.org
- Change desktop menu category to Science
* Mon Jul 30 2012 ctrippe@opensuse.org
- Update to 2.0.6, for a complete list of changes see
  http://kst-plot.kde.org/files/Log_messages_2.0.5_to_2.0.6.txt
  * When loading a kst file, prompt the user for an alternate if a
    datasource can't be found
  * Save/use arrow head property defaults
  * Don't invert Z order of viewItems which are direct children of
    the View
  * Data wizard fixes (spectrum format, speed improvements when
    there are many vectors,
  * Properly handle missing data in custom-delimited ASCII to avoid
    mixing the vectors
  * Large speedup (x10!) for ASCII with very many columns
  * Allow SVG and pixmap view objects to have adjustable aspect ratios
  * Fix apply button in view item dialogs (including labels)
- Build python-kst for scripting
* Fri Jun 29 2012 reddwarf@opensuse.org
- BuildRequire libnetcdf_c++-devel after the package split
* Mon May 21 2012 ctrippe@opensuse.org
- Update to 2.0.5
  * Data-fixed annotation objects (e.g. text and arrows which
    scroll along with the curves)
  * Support for Matlab's .mat file format for strigns, matrices,
    vectors and scalars
  * Beta version of python scripting (on Linux only for now,
    depending on NumPy 1.6 and SciPy and requiring .py and .pyc
    files installed in the right place). See documentation at
    http://hen.astro.utoronto.ca/pyKst/ and don't hesitate to ask
    for help on the mailing list as this feature is still in
    beta stage
  * Drag & Drop support: simply drop a .kst file onto Kst and it
    will open, if you drop any data file it will open in the data
    wizard
  * Improved printing to vector formats (printer, PDF, SVG)
  * Optional antialiasing (may be slow on some systems)
  * A number of bugs and crashes fixed in various areas, like
    shared axis boxes. See detailed changelog at
    http://kst-plot.kde.org/files/Log_messages_2.0.4_to_2.0.5.txt
    for more information
* Sat Mar 24 2012 idonmez@suse.com
- Depend on netcdf-devel for openSUSE >= 12.2
- Build in parallel
* Mon Oct 17 2011 toddrme2178@gmail.com
- Switched to using KDE macros
- Switched release build (this is supposed to optimize performance)
- Cleaned up spec file formatting
* Wed Sep 14 2011 ctrippe@opensuse.org
- Update to kst 2.0.4
  * A major re-write of the auto-layout command: it works much
    better now and no longer gets in the way
  * Improvements to automatic legend names
  * Fixes to the layout mode, with better visual feedback during
    drag operations
  * Numerous other bugfixes and improvements (point density,
    scientific notation, issues with log mode, bar colors, fixed
    aspect ratio in images and svg annotation items)
  * UI and usability improvements: for instance you can now just
    double-click on labels or axes to open the corresponding dialog
  * The introduction of a Settings->Theme dialog which sets brush,
    stroke, and font for all view items, optionally applying to all
    existing objects, and/or saving as the default for all future
    objects
  * A great new auto-completer for the the equation editor and
    label editor, including support for wildcards
  * A number of crashes fixed in various plugins
* Mon Apr 18 2011 ctrippe@opensuse.org
- Update to kst 2.0.3
  * cmake-based build system
  * many improvements in the reading of ASCII files: extensive UI
    overhaul and huge speedup
  * support for metadata added for netCDF files (scalar and string
    attributes) and ASCII (units and some data-file info)
  * UI improvements (new icons, consistency with KDE HIG guidelines,
    some dialogs reworked)
  * lots of bugs and crashes fixed in less-often used parts of the code
* Wed Dec 15 2010 ctrippe@gmx.net
- BuildRequire getdata-devel for openSUSE 11.4
* Mon Nov 22 2010 ctrippe@gmx.net
- Update to kst 2.0.2
  * Kst 2.0.2: Kst does not crash any more when ASCII data is imported.
  * Kst 2.0.1: Many bugfixes and polished GUI (e.g. drag and drop of plots between tabs)
- BuildRequire libnetcdf-devel
* Tue Aug 31 2010 ctrippe@gmx.net
- Update to 2.0.0
  * Fixes bnc#541957
- add export INSTALL_LIBDIR=lib64 in the build section fixes bnc#548228
* Tue Jul 14 2009 tittiatcoke@gmail.com
- Update to 2.0.0 beta 2
  * KDE4 version
* Sat Jul 11 2009 tittiatcoke@gmail.com
- update to 1.8.0:
  * Fast real-time display and manipulation of streaming data
  * Quick zooming and scrolling via mouse and keyboard
  * Extensible via plugins
  * Built-in high-speed equation interpreter
  * Multiple tabs or windows
  * Graphical plot layout manager
  * Javascript scripting
  * Drag and drop
  * Cut and paste
  * Native power spectrum algorithm and histograms
  * Image and matrix support, including waterfall plots
  * Support for the most popular data formats including:
    + ASCII, dirfile, CDF, piolib, FITS, HEALPix, qimage
    + Plugin design allows additional formats
  * Time input
  * Built-in ELOG functionality
  * Command-line and RPC control mechanisms
  * Printing, including to images, postscript, and PDF
* Sat Feb 14 2009 coolo@suse.de
- call kde_post_install before %%find_lang
* Wed Oct 22 2008 dmueller@suse.de
- update to 1.7.0:
  * Fast real-time display and manipulation of streaming data
  * Quick zooming and scrolling via mouse and keyboard
  * Extensible via plugins
  * Built-in high-speed equation interpreter
  * Multiple tabs or windows
  * Graphical plot layout manager
  * Javascript scripting
  * Drag and drop
  * Cut and paste
  * Native power spectrum algorithm and histograms
  * Image and matrix support, including waterfall plots
  * Support for the most popular data formats including:
    o ASCII, dirfile, CDF, netCDF, piolib, FITS, HEALPix, qimage
    o Plugin design allows additional formats
  * Time input
  * Built-in ELOG functionality
  * Command-line and RPC control mechanisms
  * Printing, including to images, postscript, and PDF
* Mon Jul  7 2008 dmueller@suse.de
- fix build
- fix devel package requires
* Thu Apr 24 2008 stbinner@suse.de
- update to 1.6.0: no changelog provided
* Fri Mar 14 2008 dmueller@suse.de
- fixed specfile
* Thu Mar 13 2008 dmueller@suse.de
- update to 1.5.0:
  * Fast real-time display and manipulation of streaming data
  * Quick zooming and scrolling via mouse and keyboard
  * Extensible via plugins
  * Built-in high-speed equation interpreter
  * Multiple tabs or windows
  * Graphical plot layout manager
  * Javascript scripting
  * Drag and drop
  * Cut and paste
  * Native power spectrum algorithm and histograms
  * Image and matrix support, including waterfall plots
  * Support for the most popular data formats including:
    o ASCII, dirfile, CDF, netCDF, piolib, FITS, HEALPix, qimage
    o Plugin design allows additional formats
  * Time input
  * Built-in ELOG functionality
  * Command-line and RPC control mechanisms
  * Printing, including to images, postscript, and PDF
- licensing fixes (bnc#369453)
* Wed Nov 28 2007 dmueller@suse.de
- fix build against glibc 2.7
* Sat Aug  4 2007 stbinner@suse.de
- update to version 1.4: numerous bugfixes, see ChangeLog
* Thu Jun 21 2007 stbinner@suse.de
- fix invalid .desktop file
* Fri Jun  1 2007 coolo@suse.de
- move kde_post_install
* Tue May 29 2007 coolo@suse.de
- fix translations handling
* Wed May 23 2007 stbinner@suse.de
- use %%fupes
- add missing ldconfig run calls
* Fri Oct 20 2006 stbinner@suse.de
- update to version 1.3:1: numerous deadlock and crash fixes
* Wed Sep 20 2006 stbinner@suse.de
- update to version 1.3.0: no change log digest provided
* Wed Apr 19 2006 stbinner@suse.de
- don't use broken netcdf on distributions before 10.1
* Tue Mar 28 2006 stbinner@suse.de
- update to version 1.2.1
  * countless bugfixes
* Mon Feb 20 2006 stbinner@suse.de
- cleanup BuildRequires: after gsl-devel dependency fix
* Wed Feb 15 2006 stbinner@suse.de
- update to version 1.2
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Nov 11 2005 dmueller@suse.de
- fix build
* Thu Oct 27 2005 stbinner@suse.de
- update to version 1.1.1
* Mon Oct 10 2005 stbinner@suse.de
- fix include hints for Qt 3.3.5
* Wed Oct  5 2005 stbinner@suse.de
- fix some %%files entries for 64 bit
* Tue Oct  4 2005 stbinner@suse.de
- initial package (version 1.1.0)
